Handy
=====

A collection of different tools, shortcuts, decorators, form and model fields
to make your django life easier.

Read `full docs <http://handy.readthedocs.org/>`_.


Installation
------------

::

    pip install handy
